////////////////////////////////////
// header.hh -- header collection //
////////////////////////////////////

#ifndef HEADER_HH
#define HEADER_HH

#include <iostream>
#include <fstream>
#include <cmath>
#include <cstdio>

#include <TROOT.h>
#include <TSystem.h>
#include <TFile.h>
#include <TTree.h>
#include <TChain.h>
#include <TCanvas.h>
#include <TPostScript.h>
#include <TString.h>
#include <TF1.h>
#include <TH1S.h>
#include <TH1F.h>
#include <TH1D.h>
#include <TH2D.h>
#include <TH3D.h>
#include <TGraph.h>
#include <TGraphErrors.h>
#include <TGraphAsymmErrors.h>
#include <TStyle.h>
#include <TLine.h>
#include <TLegend.h>
#include <TLatex.h>
#include <TMatrixD.h>
#include <TVectorD.h>
#include <TRandom.h>

#define PI 3.14159265358979
#define PixelnLy 3
#define PixelCTBnMod 6
#define SCTnLy 4
#define SCTCTBnMod 8
#define BLArnSamp 4
#define TilenSamp 4
#define HECnSamp 4
#define FCalnSamp 3

#endif // HEADER_HH

