#ifndef DAISUKE_MY_STYLE_H
#define DAISUKE_MY_STYLE_H 1

#include "TStyle.h"
#include "TROOT.h"

namespace MyFunctions {
  void SetMyStyle()
    {
      TStyle * plain = new TStyle("MyStyle", "my styple");
      plain->SetFrameBorderMode(0);
      plain->SetFrameLineColor(1);
      plain->SetCanvasBorderMode(0);
      plain->SetCanvasBorderSize(0);
      plain->SetCanvasColor(0);
      plain->SetPadBorderMode(0);
      plain->SetPadColor(0);
      //plain->SetTitleFontSize(0.1);
      plain->SetTitleColor(1);
      //plain->SetTitleFont(82);
      plain->SetTitleFillColor(0);
      plain->SetTitleBorderSize(1);
      plain->SetStatColor(0);
      //plain->SetStatFontSize(0.1);
      //plain->SetStatFont(82);
      plain->SetStatBorderSize(1);
      //plain->SetLabelFont(82, "X");
      //plain->SetLabelFont(82, "Y");
      //plain->SetLabelSize(0.07, "X");
      //plain->SetLabelSize(0.07, "Y");
      gROOT->SetStyle("MyStyle");
    }
} // end of namespace MyFucntions

#endif // DAISUKE_MY_STYLE_H
